==> xmonad-0.15-110-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xmonad
version:              0.15
visibility:           public
id:                   xmonad-0.15-Ak7Jyi3DadrJcCscvsvQYQ
key:                  xmonad-0.15-Ak7Jyi3DadrJcCscvsvQYQ
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:
    Spencer Janssen, Don Stewart, Adam Vogt, David Roundy, Jason Creighton,
    Brent Yorgey, Peter Jones, Peter Simons, Andrea Rossato, Devin Mullins,
    Lukas Mai, Alec Berryman, Stefan O'\''Rear, Daniel Wagner, Peter J. Jones,
    Daniel Schoepe, Karsten Schoelzel, Neil Mitchell, Joachim Breitner,
    Peter De Wachter, Eric Mertens, Geoff Reedy, Michiel Derhaeg,
    Philipp Balzarek, Valery V. Vorotyntsev, Alex Tarkovsky, Fabian Beuke,
    Felix Hirn, Michael Sloan, Tomas Janousek, Vanessa McHale, Nicolas Pouillard,
    Aaron Denney, Austin Seipp, Benno Fünfstück, Brandon S Allbery, Chris Mears,
    Christian Thiemann, Clint Adams, Daniel Neri, David Lazar, Ferenc Wagner,
    Francesco Ariis, Gábor Lipták, Ivan N. Veselov, Ivan Tarasov, Javran Cheng,
    Jens Petersen, Joey Hess, Jonne Ransijn, Josh Holland, Khudyakov Alexey,
    Klaus Weidner, Michael G. Sloan, Mikkel Christiansen, Nicolas Dudebout,
    Ondřej Súkup, Paul Hebble, Shachaf Ben-Kiki, Siim Põder, Tim McIver,
    Trevor Elliott, Wouter Swierstra, Conrad Irwin, Tim Thelion

homepage:             http://xmonad.org
synopsis:             A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from the
    keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other extensions,
    may be written by the user in config files. Layouts are applied
    dynamically, and different layouts may be used on each workspace.
    Xinerama is fully supported, allowing windows to be tiled on several
    screens.

category:             System
abi:                  32c27b284f3dfd2d288c55991b74c843
exposed:              True
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet

hidden-modules:       Paths_xmonad
import-dirs:          /usr/lib/ghc-8.10.4/site-local/xmonad-0.15
library-dirs:         /usr/lib/ghc-8.10.4/site-local/xmonad-0.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad
hs-libraries:         HSxmonad-0.15-Ak7Jyi3DadrJcCscvsvQYQ
depends:
    X11-1.9.2-ENktjCLCc4t7wb9UwULJwT base-4.14.1.0 containers-0.6.2.1
    data-default-0.7.1.1-IbF6nDffyZnL9pNi4JmXiu directory-1.3.6.0
    extensible-exceptions-0.1.1.4-DY91N4N9LFmCiQpNXwJXMT
    filepath-1.4.2.1 mtl-2.2.2 process-1.6.9.0
    setlocale-1.0.0.9-AJemP3N3a0pICB4jHluTy6 unix-2.7.2.2
    utf8-string-1.0.2-8tSNItKZaZx3RInHCj3b5n

haddock-interfaces:   /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html:         /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-0.15-113-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xmonad
version:              0.15
visibility:           public
id:                   xmonad-0.15-1Vwc5FoSZfx6Vsxacie0H7
key:                  xmonad-0.15-1Vwc5FoSZfx6Vsxacie0H7
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:
    Spencer Janssen, Don Stewart, Adam Vogt, David Roundy, Jason Creighton,
    Brent Yorgey, Peter Jones, Peter Simons, Andrea Rossato, Devin Mullins,
    Lukas Mai, Alec Berryman, Stefan O'\''Rear, Daniel Wagner, Peter J. Jones,
    Daniel Schoepe, Karsten Schoelzel, Neil Mitchell, Joachim Breitner,
    Peter De Wachter, Eric Mertens, Geoff Reedy, Michiel Derhaeg,
    Philipp Balzarek, Valery V. Vorotyntsev, Alex Tarkovsky, Fabian Beuke,
    Felix Hirn, Michael Sloan, Tomas Janousek, Vanessa McHale, Nicolas Pouillard,
    Aaron Denney, Austin Seipp, Benno Fünfstück, Brandon S Allbery, Chris Mears,
    Christian Thiemann, Clint Adams, Daniel Neri, David Lazar, Ferenc Wagner,
    Francesco Ariis, Gábor Lipták, Ivan N. Veselov, Ivan Tarasov, Javran Cheng,
    Jens Petersen, Joey Hess, Jonne Ransijn, Josh Holland, Khudyakov Alexey,
    Klaus Weidner, Michael G. Sloan, Mikkel Christiansen, Nicolas Dudebout,
    Ondřej Súkup, Paul Hebble, Shachaf Ben-Kiki, Siim Põder, Tim McIver,
    Trevor Elliott, Wouter Swierstra, Conrad Irwin, Tim Thelion

homepage:             http://xmonad.org
synopsis:             A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from the
    keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other extensions,
    may be written by the user in config files. Layouts are applied
    dynamically, and different layouts may be used on each workspace.
    Xinerama is fully supported, allowing windows to be tiled on several
    screens.

category:             System
abi:                  a8fbc6aa6348e7a5dffdb6b987566714
exposed:              True
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet

hidden-modules:       Paths_xmonad
import-dirs:          /usr/lib/ghc-8.10.4/site-local/xmonad-0.15
library-dirs:         /usr/lib/ghc-8.10.4/site-local/xmonad-0.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad
hs-libraries:         HSxmonad-0.15-1Vwc5FoSZfx6Vsxacie0H7
depends:
    X11-1.9.2-JuqOkXPYHHHDX5QPzci7Ja base-4.14.1.0 containers-0.6.2.1
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV directory-1.3.6.0
    extensible-exceptions-0.1.1.4-DY91N4N9LFmCiQpNXwJXMT
    filepath-1.4.2.1 mtl-2.2.2 process-1.6.9.0
    setlocale-1.0.0.9-AJemP3N3a0pICB4jHluTy6 unix-2.7.2.2
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV

haddock-interfaces:   /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html:         /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
